1. Explicitly set the `filename` attribute in the Content-disposition
HTTP response header.

2. Perform strict whitelist validation on user input before using it
in the creation of HTTP response bodies
